==> openGion_dev_5.1.9.0.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/column/Renderer_MULTIQUERY.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.fukurou.db.DBUtil;
import org.opengion.fukurou.util.ApplicationInfo;
import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.db.AbstractRenderer;
import org.opengion.hayabusa.db.CellRenderer;
import org.opengion.hayabusa.db.DBColumn;
import org.opengion.hayabusa.html.StringFormat;

/**
 * MULTIQUERY レンデラーは、表示パラメータで指定された SQL文の実行結果を表示するクラスです。
 * 
 * 複数件のデータが取得された場合、各データは、spanタグで囲われて返されます。
 *  <span>値1</span><span>値2</span><span>値3</span>
 * 
 * 第2カラムを指定した場合、その値は、spanタグのclass属性として付加されます。
 * 
 * また、SQL文の指定には、元のValue を、$1 として使用可能です。
 * ($Cで自身のカラム名を参照することも可能です)
 *
 * カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.rev 5.1.8.0 (2010/07/01) 新規追加
 * @og.group データ表示
 *
 * @version  5.0
 * @author   Hiroki Nakamura
 * @since    JDK5.0,
 */
public class Renderer_MULTIQUERY extends AbstractRenderer {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.1.8.0 (2010/07/01)" ;

	private final String query;
	private final String dbid;
	private final String name;

	/** コネクションにアプリケーション情報を追記するかどうか指定 */
	public static final boolean USE_DB_APPLICATION_INFO  = HybsSystem.sysBool( "USE_DB_APPLICATION_INFO" ) ;

	private final ApplicationInfo appInfo;
	private static final String SYSTEM_ID  = HybsSystem.sys( "SYSTEM_ID" ) ;

	/**
	 * デフォルトコンストラクター。
	 * このコンストラクターで、基本オブジェクトを作成します。
	 */
	public Renderer_MULTIQUERY() {
		query   = null;
		dbid	= null;
		appInfo = makeApplicationInfo( null );
		name	= null;
	}

	/**
	 * デフォルトコンストラクター。
	 *
	 * @param   clm DBColumn オブジェクト
	 */
	private Renderer_MULTIQUERY( final DBColumn clm ) {
		query = clm.getRendererParam();
		dbid  = clm.getDbid();
		appInfo = makeApplicationInfo( clm.getName() );
		name  = clm.getName(); 
	}

	/**
	 * アクセスログ取得の為,ApplicationInfo オブジェクトを作成します。 <br />
	 *
	 * @param   name String オブジェクト
	 * @return ApplicationInfo
	 */
	private ApplicationInfo makeApplicationInfo( final String name ) {
		ApplicationInfo infoTemp = null;

		if( USE_DB_APPLICATION_INFO ) {
			infoTemp = new ApplicationInfo();
			// ユーザーID,IPアドレス,ホスト名
			infoTemp.setClientInfo( SYSTEM_ID,HybsSystem.HOST_ADRS,HybsSystem.HOST_NAME );
			// 画面ID,操作,プログラムID
			infoTemp.setModuleInfo( "Renderer_MULTIQUERY",null,name );
		}

		return infoTemp ;
	}

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @param   clm DBColumn オブジェクト
	 * @return  CellRenderer オブジェクト
	 */
	public CellRenderer newInstance( final DBColumn clm ) {
		return new Renderer_MULTIQUERY( clm );
	}

	/**
	 * データの表示用文字列を返します。
	 *
	 * ここでは、AAA:BBB:CCC:DDD という値を、$1,$2,$3,$4 に割り当てなおして、
	 * QUERYを実行します。また、$1 は、本来の値として、メニューの初期値設定等に
	 * 使用します。上記の例では、AAA が値で、それ以降は、引数になります。
	 * さらに、元の文字列"AAA:BBB:CCC:DDD"は、$0 に割り当てられます。割り当てがない
	 * 変数は、""(ゼロ文字列)として、扱われます。<br />
	 * 又、$Cには自分自身のカラム名を割り当てます。<br />
	 * 
	 * 複数件のデータが取得された場合、各データは、spanタグで囲われて返されます。
	 *  <span>値1</span><span>値2</span><span>値3</span>
	 *  第2カラムを指定した場合、その値は、spanタグのclass属性として付加されます
	 *
	 * @param   value String
	 * @return  データの表示用文字列
	 */
	public String getValue( final String value ) {
		StringFormat format = new StringFormat( query, value, name );
		String str = format.format();

		String[][] rtn = DBUtil.dbExecute( str, null, appInfo, dbid );

		String val = "";
		if( rtn != null && rtn.length > 0 && rtn[0] != null && rtn[0].length > 0 ) {
			boolean isUseClass = false;
			if( rtn[0].length > 1 ) {
				isUseClass = true;
			}
			StringBuilder buf = new StringBuilder();
			for( int i=0; i<rtn.length; i++ ) {
				buf.append( "<span" );
				if( isUseClass ) {
					buf.append( " class=\"" ).append( rtn[i][1] ).append( "\"" );
				}
				buf.append( ">" ).append( rtn[i][0] ).append( "</span>" );
			}
			val = buf.toString();
		}

		return val;
	}
}

==> openGion_dev_5.3.9.0.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/column/Renderer_MULTIQUERY.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.fukurou.db.DBUtil;
import org.opengion.fukurou.util.ApplicationInfo;
import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.db.AbstractRenderer;
import org.opengion.hayabusa.db.CellRenderer;
import org.opengion.hayabusa.db.DBColumn;
import org.opengion.fukurou.util.StringFormat;

/**
 * MULTIQUERY レンデラーは、表示パラメータで指定された SQL文の実行結果を表示するクラスです。
 * 
 * 複数件のデータが取得された場合、各データは、spanタグで囲われて返されます。
 *  <span>値1</span><span>値2</span><span>値3</span>
 * 
 * 第2カラムを指定した場合、その値は、spanタグのclass属性として付加されます。
 * 
 * また、SQL文の指定には、元のValue を、$1 として使用可能です。
 * ($Cで自身のカラム名を参照することも可能です)
 *
 * カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.rev 5.1.8.0 (2010/07/01) 新規追加
 * @og.group データ表示
 *
 * @version  5.0
 * @author   Hiroki Nakamura
 * @since    JDK5.0,
 */
public class Renderer_MULTIQUERY extends AbstractRenderer {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.1.8.0 (2010/07/01)" ;

	private final String query;
	private final String dbid;
	private final String name;

	/** コネクションにアプリケーション情報を追記するかどうか指定 */
	public static final boolean USE_DB_APPLICATION_INFO  = HybsSystem.sysBool( "USE_DB_APPLICATION_INFO" ) ;

	private final ApplicationInfo appInfo;
	private static final String SYSTEM_ID  = HybsSystem.sys( "SYSTEM_ID" ) ;

	/**
	 * デフォルトコンストラクター。
	 * このコンストラクターで、基本オブジェクトを作成します。
	 */
	public Renderer_MULTIQUERY() {
		query   = null;
		dbid	= null;
		appInfo = makeApplicationInfo( null );
		name	= null;
	}

	/**
	 * デフォルトコンストラクター。
	 *
	 * @param   clm DBColumn オブジェクト
	 */
	private Renderer_MULTIQUERY( final DBColumn clm ) {
		query = clm.getRendererParam();
		dbid  = clm.getDbid();
		appInfo = makeApplicationInfo( clm.getName() );
		name  = clm.getName(); 
	}

	/**
	 * アクセスログ取得の為,ApplicationInfo オブジェクトを作成します。 <br />
	 *
	 * @param   name String オブジェクト
	 * @return ApplicationInfo オブジェクト
	 */
	private ApplicationInfo makeApplicationInfo( final String name ) {
		ApplicationInfo infoTemp = null;

		if( USE_DB_APPLICATION_INFO ) {
			infoTemp = new ApplicationInfo();
			// ユーザーID,IPアドレス,ホスト名
			infoTemp.setClientInfo( SYSTEM_ID,HybsSystem.HOST_ADRS,HybsSystem.HOST_NAME );
			// 画面ID,操作,プログラムID
			infoTemp.setModuleInfo( "Renderer_MULTIQUERY",null,name );
		}

		return infoTemp ;
	}

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @param   clm DBColumn オブジェクト
	 * @return  CellRenderer オブジェクト
	 */
	public CellRenderer newInstance( final DBColumn clm ) {
		return new Renderer_MULTIQUERY( clm );
	}

	/**
	 * データの表示用文字列を返します。
	 *
	 * ここでは、AAA:BBB:CCC:DDD という値を、$1,$2,$3,$4 に割り当てなおして、
	 * QUERYを実行します。また、$1 は、本来の値として、メニューの初期値設定等に
	 * 使用します。上記の例では、AAA が値で、それ以降は、引数になります。
	 * さらに、元の文字列"AAA:BBB:CCC:DDD"は、$0 に割り当てられます。割り当てがない
	 * 変数は、""(ゼロ文字列)として、扱われます。<br />
	 * 又、$Cには自分自身のカラム名を割り当てます。<br />
	 * 
	 * 複数件のデータが取得された場合、各データは、spanタグで囲われて返されます。
	 *  <span>値1</span><span>値2</span><span>値3</span>
	 *  第2カラムを指定した場合、その値は、spanタグのclass属性として付加されます
	 *
	 * @param   value String
	 * @return  データの表示用文字列
	 */
	public String getValue( final String value ) {
		StringFormat format = new StringFormat( query, value, name );
		String str = format.format();

		String[][] rtn = DBUtil.dbExecute( str, null, appInfo, dbid );

		String val = "";
		if( rtn != null && rtn.length > 0 && rtn[0] != null && rtn[0].length > 0 ) {
			boolean isUseClass = false;
			if( rtn[0].length > 1 ) {
				isUseClass = true;
			}
			StringBuilder buf = new StringBuilder();
			for( int i=0; i<rtn.length; i++ ) {
				buf.append( "<span" );
				if( isUseClass ) {
					buf.append( " class=\"" ).append( rtn[i][1] ).append( "\"" );
				}
				buf.append( ">" ).append( rtn[i][0] ).append( "</span>" );
			}
			val = buf.toString();
		}

		return val;
	}
}
